
***************************** FINAL STATA DO FILE: INCORPORATING MARGINAL CITIZENS AND VOTERS *******************************************************
***************************** MATTHEW L. LAYTON AND AMY ERICA SMITH, COMPARATIVE POLITICAL STUDIES **************************************************
***************************** PLEASE CONTACT THE AUTHORS WITH ANY QUESTIONS: AMYERICAS@GMAIL.COM AND MATTHEW.L.LAYTON@VANDERBILT.EDU


***************************** THIS ANALYSIS REQUIRES THE LAPOP MERGED AMERICASBAROMETER 2012 DATA, V49.0, WHICH MAY BE OBTAINED FROM LAPOP:
***************************** http://www.vanderbilt.edu/lapop/request-datasets.php
***************************** THE 2012 QUESTIONNAIRE SERVES AS THE CODEBOOK FOR THE DATA: 
***************************** http://www.vanderbilt.edu/lapop/ab2012/ABCor12-v10.0-Eng-120222_W.pdf


***************************** SECTIONS OF THIS DOCUMENT:
***************************** I. SET UP FILES
***************************** II. CREATE REPLICATION DATA SET CONTAINING NEW VARIABLES (SECTION MAY BE SKIPPED IF YOU HAVE DOWNLOADED THE DATA FROM CPS)
***************************** III. MERGE LAPOP AND REPLICATION DATA 
***************************** IV. STATA ANALYSIS: MAIN TABLES AND FIGURES FROM PAPER (EXCEPT HIERARCHICAL RESULTS) 
***************************** V. STATA ANALYSIS: TABLES AND FIGURES FROM APPENDICES (EXCEPT HIERARCHICAL RESULTS) 
***************************** VI. STATA ANALYSIS: ANALYSIS FROM FOOTNOTES AND IN-TEXT DISCUSSION
***************************** VII. PREPARATION OF DATA FOR EXPORT TO HLM SOFTWARE
***************************** VIII. CODE FOR FIGURE BASED ON HIERARCHICAL ANALYSIS USING HLM SOFTWARE


****************************** I. SET UP FILES *********************************************************************************************************
**** SET WORKING DIRECTORY 
cd "YOUR PATH DIRECTORY HERE"
**** OPEN THE LAPOP MERGED AMERICASBAROMETER 2012 DATA, V49.0, WHICH MAY BE OBTAINED FROM LAPOP
use "AmericasBarometer Merged 2012 v49.0 English.dta", clear
**** ELIMINATE THE US AND CANADA FROM THE ANALYSIS; MANY MEASURES NOT ASKED IN THOSE COUNTRIES
drop if pais > 39 
**** SET COUNTRY AS A SECOND-LEVEL VARIABLE FOR HIERARCHICAL ANALYSIS
xtset pais
**** CREATE A UNIQUE ID TO BE USED TO MATCH THE LAPOP DATA SET WITH THE REPLICATION DATA SET CONTAINING NEW VARIABLES
g uniqueid = _n 


****************************** II. CREATE REPLICATION DATA **********************************************************************************************
********************* THIS DATA SET CONTAINS ONLY NEW VARIABLES NOT CONTAINED IN "AmericasBarometer Merged 2012 v49.0 English.dta", DISTRIBUTED BY LAPOP
********************* IF YOU HAVE DOWNLOADED THE REPLICATION DATA FROM CPS, YOU MAY SKIP THIS SECTION
preserve
g deleteeverythingabovehere = . //CREATES A NEW VARIABLE TO DELIMIT THE NEW VARIABLES AT THE BOTTOM OF THE DATA SET
move uniqueid deleteeverythingabovehere

*** DELETE PREVIOUSLY RECODED VARIABLES FROM AMERICASBAROMETER MERGED DATABASE
foreach i in soct1r idio1r PSA5 ing4r vic1extr EFICGOV rolestado eff2r community cp6r cp7r cp8r {
	capture drop `i'
}

*** CREATE A NEW MARKER FOR COUNTRY THAT IS AN UNINTERRUPTED SERIES OF INTEGERS
egen country = group(pais)
lab def country 1 "Mexico" 2 "Guatemala" 3 "El Salvador" 4 "Honduras" 5 "Nicaragua" 6 "Costa Rica" 7 "Panama" ///
	8 "Colombia" 9 "Ecuador" 10 "Bolivia" 11 "Peru" 12 "Paraguay" 13  "Chile" 14  "Uruguay" 15 "Brazil" 16 "Venezuela" 17 "Argentina" ///
	18 "Dom. Rep." 19 "Haiti" 20 "Jamaica" 21 "Guyana" 22 "Trinidad & Tobago" 23 "Belize" 24 "Suriname"
lab val country country

**** CODE AN ALTERNATIVE VERSION OF THE DEPENDENT VARIABLE, INCLUDING NON-RESPONDENTS AS NON-VOTERS
recode vb20 (.a .b .c = 1), g(vb20_withnr)

**** CREATE A MARKER FOR EACH COMBINATION OF COUNTRY AND VOTE CHOICE
egen tag_pais_vb20 = tag(pais vb20) 

******** CODE VARIABLES FOR PUBLIC ASSISTANCE RECEIPT
*** PRIMARY INDEPENDENT VARIABLE
drop cct1newr // LAPOP HAD ALREADY RECODED THIS VARIABLE
recode cct1new (2 = 0), g(cct1newr)
lab var cct1newr "Assistance Beneficiary"
lab def cct1newr 0 "Non-Beneficiary" 1 "Beneficiary", modify
lab val cct1newr cct1newr
*** RECIPIENTS OF PARTICULAR CCT PROGRAMS
/*
MEX: Oportunidades; COSTA RICA: Avancemos; COLOMBIA: Familias en Accin; ECUADOR: Bono de Desarrollo Humano; PERU: Programa Juntos; 
CHILE: Programa Chile Solidario; BRAZIL: Programa Bolsa Famlia; ARGENTINA: Asignacin Universal por Hijo; DOMINICAN REPUBLIC: Tarjeta de Solidaridad
*/
g cct1br = (cct1b >= 101 & cct1b < .) if cct1b < .
g cct1b_asked = cct1b < .
*** PEOPLE WHO SAID THEY RECEIVE ASSISTANCE, BUT SAID THEY *DIDN'T* RECEIVE THE MAIN CCT
g cct1_other = (cct1newr == 1 & cct1br == 0) if cct1b_asked == 1

*** CODE PID
replace vb11=. if (vb10==.a | vb10==.b)
gen no_pid=vb10-1
replace no_pid=	1 if (vb11==.a | vb11==.b | vb11==.c) & (vb10==1)
gen gov_pid=0 if no_pid != .
replace gov_pid= 1 if vb11== 101 | vb11== 206 | vb11== 302 | vb11== 401 | vb11== 502 | vb11== 602 | vb11== 702 | vb11== 804 | vb11== 913 | ///
	vb11== 1002 | vb11== 1101 | vb11== 1202 | vb11== 1304 | vb11== 1305 | vb11== 1401 | vb11== 1501 | vb11== 1611 | vb11== 1701 | vb11== 2102 | ///
	vb11== 2204 | vb11== 2301 | vb11== 2401 | vb11== 2502 | vb11== 2503 | vb11== 2504 | vb11== 2506 | vb11== 2601 | vb11== 2707 
lab var gov_pid "Government Partisan"
gen opp_pid=0 if no_pid != .
replace opp_pid= 1 if vb11== 77 | vb11== 102 | vb11== 103 | vb11== 104 | vb11== 105 | vb11== 108 | vb11== 202 | vb11== 203 | vb11== 205 | ///
	vb11== 208 | vb11== 209 | vb11== 211 | vb11== 212 | vb11== 301 | vb11== 303 | vb11== 304 | vb11== 305 | vb11== 306 | vb11== 402 | ///
	vb11== 403 | vb11== 404 | vb11== 501 | vb11== 504 | vb11== 601 | vb11== 603 | vb11== 604 | vb11== 701 | vb11== 703 | vb11== 704 | ///
	vb11== 705 | vb11== 706 | vb11== 801 | vb11== 802 | vb11== 803 | vb11== 805 | vb11== 808 | vb11== 810 | vb11== 817 | vb11== 821 | ///
	vb11== 823 | vb11== 826 | vb11== 901 | vb11== 902 | vb11== 903 | vb11== 904 | vb11== 905 | vb11== 906 | vb11== 907 | vb11== 908 | ///
	vb11== 909 | vb11== 911 | vb11== 912 | vb11== 1004 | vb11== 1007 | vb11== 1009 | vb11== 1010 | vb11== 1102 | vb11== 1103 | vb11== 1104 | ///
	vb11== 1105 | vb11== 1201 | vb11== 1203 | vb11== 1204 | vb11== 1205 | vb11== 1206 | vb11== 1207 | vb11== 1208 | vb11== 1212 | vb11== 1213 | ///
	vb11== 1215 | vb11== 1301 | vb11== 1302 | vb11== 1303 | vb11== 1306 | vb11== 1307 | vb11== 1402 | vb11== 1403 | vb11== 1404 | vb11== 1502 | ///
	vb11== 1503 | vb11== 1504 | vb11== 1505 | vb11== 1506 | vb11== 1507 | vb11== 1508 | vb11== 1509 | vb11== 1510 | vb11== 1511 | vb11== 1512 | ///
	vb11== 1513 | vb11== 1602 | vb11== 1603 | vb11== 1604 | vb11== 1608 | vb11== 1612 | vb11== 1613 | vb11== 1614 | vb11== 1615 | vb11== 1617 | ///
	vb11== 1624 | vb11== 1702 | vb11== 1703 | vb11== 1704 | vb11== 1705 | vb11== 1707 | vb11== 2101 | vb11== 2103 | vb11== 2201 | vb11== 2202 | ///
	vb11== 2203 | vb11== 2205 | vb11== 2206 | vb11== 2207 | vb11== 2208 | vb11== 2209 | vb11== 2210 | vb11== 2211 | vb11== 2212 | vb11== 2302 | ///
	vb11== 2303 | vb11== 2402 | vb11== 2403 | vb11== 2501 | vb11== 2602 | vb11== 2603 | vb11== 2607 | vb11== 2703 | vb11== 2704 | vb11== 2706 | ///
	vb11== 2709 | vb11== 2710 | vb11== 2711 | vb11== 2712 | vb11== 2713 | vb11== 2715 | vb11== 2716 | vb11== 2719 | vb11== 2721 | vb11== 2723 | ///
	vb11== 2736 
lab var opp_pid "Opposition Partisan"

*** CODE OTHER INDIVIDUAL-LEVEL CONTROL VARIABLES
g unemployment = (ocup4a == 3) if (ocup4a < .)
lab var unemployment "Personal Unemployment"

recode q10e (3 = 1) (1 2 = 0), g(incomedes)
lab var incomedes "Drop in Household Income"

g age_sq = q2^2
lab var age_sq "Age Squared"
tab edad, g(edad)

g soct1r=(5-soct1)/4
lab var soct1r "Perception of National Economic Situation"

gen idio1r=(5-idio1)/4
lab var idio1r "Perception of Personal Economic Situation"

egen misPSA5=rowmiss(b1 b2 b3 b4 b6)
egen PSA5= rowmean(b1 b2 b3 b4 b6) if misPSA5<=2
replace PSA5=(PSA5-1)/6
drop misPSA5
lab var PSA5 "System Support"

g ing4r = (ing4-1)/6
lab var ing4r "Support for Democracy"

g vic1extr=2-vic1ext
label variable vic1extr "Crime Victimization"

egen misEFICGOV=rowmiss(n1 n3 n9 n11)
egen EFICGOV = rowmean(n1 n3 n9 n11) if misEFICGOV<=2
replace EFICGOV = (EFICGOV-1)/6
drop misEFICGOV
label variable  EFICGOV "Effectiveness of Current Administration"

egen misrolestado= rowmiss(ros2 ros3 ros4 ros6)
egen rolestado= rowmean (ros2 ros3 ros4 ros6) if misrolestado<=2 
replace rolestado = (rolestado-1)/6
drop misrolestado
lab var rolestado "Role of the State"

g eff2r = (eff2-1)/6
lab var eff2r "Understand Most Important Political Issues"

recode cp6 (4=0) (3=.33) (2=.66) (1=1), g(cp6r)
recode cp7 (4=0) (3=.33) (2=.66) (1=1), g(cp7r)
recode cp8 (4=0) (3=.33) (2=.66) (1=1), g(cp8r)
egen community = rowmean(cp6r cp7r cp8r)
drop cp6r cp7r cp8r
lab var community "Community Participation"

lab var exc6 "Government Employee Requested Bribe"

*********** CODE COUNTRY-LEVEL VARIABLES: SEE PAPER TEXT FOR SOURCES 
**** LEFTIST PRESIDENT
g leftistpresident = 1 
replace leftistpresident = 0 if pais == 1 | pais == 2 | pais == 4 | pais == 7 | pais == 8 | pais == 13 | ///
	pais == 21 | pais == 22 | pais == 26 | pais == 27
lab var leftistpresident "Leftist President"

**** COMPULSORY VOTING
generate voting=1 if pais==1 | pais==3
	replace voting=2 if pais==2 | pais==5 | pais==7 | pais==8 | pais==13 | pais==22 | pais==23 | pais==24 | pais==25 | pais==26 | pais==27
	replace voting=3 if pais==4 | pais==6 | pais==9 | pais==10 | pais==11 | pais==12 | pais==14 | pais==15 | pais==16 | pais==17 | pais==21
	label variable voting "Voting Legislation"
	label define voting_label 1 "Voluntary (no enforcement)" 2 "Voluntary" 3 "Compulsory and regulated"
	label values voting voting_label
g compulsory = voting == 3
	lab var compulsory "Compulsory Voting"

**** CCT PROGRAM CONDITIONALITY
*Nicaragua (pais==5), Haiti (pais==22), Guyana (pais==24) not coded (no current CCT or UCT)
*Belize (pais==26) not coded (now has CCT, but there is no data on enforcement)
*Suriname (pais==27) not coded (only recently received funding from IDB to create CCT)
gen conditional=1 if pais==1|pais==2|pais==3|pais==6|pais==8|pais==13|pais==14|pais==15|pais==17|pais==21|pais==23
	replace conditional=2 if pais==4|pais==7|pais==9|pais==11|pais==12|pais==25|pais==10
	replace conditional=3 if pais==16
	label define conditional 1"Conditional-Enforced" 2"Conditional-Unenforced" 3"Unconditional"
	label values conditional conditional
recode conditional (2 3 = 0), g(conditional_enforced)
	lab var conditional "Program Unconditional" 

**** PROGRAM ADMINISTERED BY AGENCY OR PRESIDENTS' OFFICE?
**	No hierarchical data for pais == 5, 22, 24, 26, 27
g presidentsoffice = (pais==8|pais==21|pais==3|pais==4|pais==12|pais==11|pais==16) if pais != 5 & pais!=22 & pais != 24 & pais != 26

************** SAVE REPLICATION DATA SET INCLUDING ONLY NEW VARIABLES
drop year-deleteeverythingabovehere
save "Rep_Data_Layton_Smith_Stata.dta", replace
restore

	
****************************** III. MERGE LAPOP AND REPLICATION DATA ****************************************************************************************
merge 1:1 uniqueid using "Rep_Data_Layton_Smith_Stata.dta", update replace

	
***************************** IV. STATA ANALYSIS: MAIN TABLES AND FIGURES FROM PAPER (EXCEPT HIERARCHICAL RESULTS) ******************************************
***** TABLE 2. THE "MAIN" MULTINOMIAL MODEL
eststo clear
xi: svy: mlogit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if pais != 22
eststo
esttab, b(3) se(3) pr2 ar2 nogaps nopar wide star(^ .10 * .05 ** .01 *** .001) label 

***** FIGURE 1. PREDICTED PROBS 
global results ""
forvalues i = 1/4 {
	xi: svy: mlogit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
		exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if pais != 22
	preserve
		egen tag_pais_cct1newr = tag(pais cct1newr) if e(sample)
		foreach j in gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
			exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community {
				egen mean_`j' = mean(`j'), by(pais)
				replace `j' = mean_`j' if e(sample)
			}
		margins if tag_pais_cct1new == 1, at(cct1newr=(0 1)) predict(outcome(`i')) post
		parmest, format(estimate min95 max95 p %8.3f p %8.1e) idstr(`i') saving(prob_outcome`i', replace) flist(results)
	restore
}
preserve
clear 
append using $results
rename idstr outcome
	destring outcome, replace
	lab def outcome 1 "Abstain" 2 "Incumbent Vote" 3 "Opposition Vote" 4 "Blank Vote"
	lab val outcome outcome
rename parm cct1newr
	replace cct1newr = "0" if cct1newr == "1._at"
	replace cct1newr = "1" if cct1newr == "2._at"
	destring cct1newr, replace
	lab def cct1newr 0 "Non-Beneficiary" 1 "Beneficiary", modify
	lab val cct1newr cct1newr
	lab var cct1newr ""
g outcome_cctstatus = (outcome-1)*3+cct1newr
graph twoway (bar estimate outcome_cctstatus if cct1newr == 0, lcolor(black) fcolor(gs10)) ///
	(bar estimate outcome_cctstatus if cct1newr == 1, lcolor(black) fcolor(gs3)) ///
	(rspike min95 max95 outcome_cctstatus , lcolor(black) lwidth(vthin)), ///
	legend(order(1 "Non-Beneficiary" 2 "Beneficiary")) ///
	ytitle("Predicted Probability of Each Outcome", size(med) margin(small)) xtitle("") ///
	ylabel(0(.1).4, format(%9.1f) grid) xlabel(0.5 "Abstain" 3.5 "Incumbent Vote" 6.5 "Opposition Vote" 9.5 "Blank Vote", notick) ///
	graphregion(fcolor(white)) saving("Figure 1.gph", replace)
restore
	
***** FIGURE 2. MARGINAL EFFECTS, BY COUNTRY TYPE (RUNNING THESE MODELS TAKES ABOUT 15 MINUTES ON AMY ERICA'S COMPUTER)
global results ""
foreach c in compulsory conditional_enforced presidentsoffice leftistpresident {
	foreach v in 0 1 {
		forvalues i = 1/4 {
			xi: svy: mlogit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
				exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais ///
				if pais != 22 & `c' == `v', base(2)
			preserve
			egen tag_pais_cct1newr = tag(pais cct1newr) if e(sample)
			foreach j in gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
				exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community {
					egen mean_`j' = mean(`j'), by(pais)
					replace `j' = mean_`j' if e(sample)
				}
			margins if tag_pais_cct1newr == 1, dydx(cct1newr) predict(outcome(`i')) post
			parmest, format(estimate min95 max95 p %8.3f p %8.1e) idstr(`c'`v'_outcome`i') saving(coefficients\prob_`c'`v'_outcome`i', replace) flist(results)
			restore
		}
	}
}
preserve
clear 
append using $results
**** CODE FOR FIGURE, ONCE RESULTS ARE IN MEMORY
**** GIVEN HOW LONG IT TAKES TO RUN THE MODELS, YOU COULD CHOOSE TO LOAD THE RESULTS MANUALLY ONCE THE COEFFICIENTS FILE HAS BEEN PRODUCED.
egen outcome = ends(idstr), punct(_outcome) tail
	destring outcome, replace
	replace outcome = 5-outcome
	lab def outcome 4 "Abstain" 3 "Incumbent Vote" 2 "Opposition Vote" 1 "Blank Vote"
	lab val outcome outcome
egen countrytype2 = ends(idstr), punct(_outcome) head
	encode countrytype2, g(countrytype)
	lab def countrytype 1 "Voluntary/Compulsory Unenforced" 2 "Compulsory Voting" 3 "No Conditionalities/Unenforced" 4 "Conditionalities" ///
		5 "Centrist/Rightist President" 6 "Leftist President" 7 "Agency Control of Program" 8 "Presidential Control", modify
	lab val countrytype countrytype
drop countrytype2 idstr parm
g countrytype_outcome = (countrytype - 1)*5 + outcome if countrytype < 3
replace countrytype_outcome = (countrytype -1)*5 + outcome + 1 if countrytype > 2 & countrytype < 5
replace countrytype_outcome = (countrytype -1)*5 + outcome + 2 if countrytype > 4 & countrytype < 7
replace countrytype_outcome = (countrytype -1)*5 + outcome + 3 if countrytype > 6 
graph twoway (bar estimate countrytype_outcome if outcome == 1, horizontal lcolor(black) fcolor(gs16)) ///
	(bar estimate countrytype_outcome if outcome == 2, horizontal lcolor(black) fcolor(gs11)) ///
	(bar estimate countrytype_outcome if outcome == 3, horizontal lcolor(black) fcolor(gs6)) ///
	(bar estimate countrytype_outcome if outcome == 4, horizontal lcolor(black) fcolor(gs1)) ///
	(rspike min95 max95 countrytype_outcome, horizontal color(black) lwidth(vthin)), ///
	legend(order(4 "Abstain" 3 "Incumbent" 2 "Opposition" 1 "Blank Vote") size(vsmall)) xline(0, lcolor(black) lwidth(vthin)) ///
	title("Marginal Effect of Receiving Social Assistance" "on Outcome, By Country Type", color(black) size(medium) margin(medium) span) ///
	xtitle("") xlabel(, format(%9.2f) grid) ///
	ytitle("") ylabel(6 "VOTING LEGISLATION" 4 "Voluntary/" 3 "Unenforced" 9 "Compulsory" ///
		17 "CONDITIONALITIES" 15 "None/Unenforced" 20 "Enforced" ///
		28 "IDEOLOGY OF PRESIDENT" 26 "Centrist/Rightist" 31 "Leftist" ///
		39 "CONTROL OF PROGRAM" 37 "Agency" 42 "President", angle(horizontal) notick nogrid labsize(small)) ///
	note("NOTE: Effects represent the change in probability of each outcome" ///
	"for recipients minus non-recipients, for each country type, based" ///
	"on multinomial logistic regression models as specified in Table 2.", span) ///
	ysize(9) graphregion(fcolor(white)) saving("Figure 2.gph", replace)
** NOTE: THE LABELS FOR THE LEVEL 2 VARIABLES IN THE RESULTING FIGURE ARE PLACED HORIZONTALLY, BETWEEN THE SUB-LABELS. 
** TO ADJUST THE POSITION, YOU NEED TO USE "GRAPH EDITOR" WITHIN STATA AFTER THE FIGURE APPEARS. 
** CLICK ON THE LABEL TO BE ADJUSTED, CHOOSE "TICK/LABEL PROPERTIES," AND CHOOSE "CUSTOM LABEL."
restore

	
***************************** V. STATA ANALYSIS: MAIN TABLES AND FIGURES FROM ONLINE APPENDIX (EXCEPT HIERARCHICAL RESULTS) **************************
******* APPENDIX TABLE 1 (AND FOOTNOTE 7): RECODING NON-RESPONSES AS ABSTAINING
eststo clear
xi: svy: mlogit vb20_withnr cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if pais != 22, base(2)
eststo
esttab, b(3) se(3) pr2 ar2 nogaps nopar wide star(^ .10 * .05 ** .01 *** .001) label 

**** APPENDIX TABLE 2. THE "MAIN" MULTINOMIAL MODEL, USING ALTERNATIVE INDEPENDENT VARIABLES
eststo clear
xi: svy: mlogit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if cct1b_asked == 1
eststo
xi: svy: mlogit vb20 cct1br cct1_other gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if cct1b_asked == 1
eststo
esttab, b(3) se(3) pr2 ar2 nogaps nopar wide star(^ .10 * .05 ** .01 *** .001) keep(cct1newr cct1br cct1_other) label 
tab1 pais if e(sample)
lincom [Would_vote_for_a_candidate_or_pa]cct1br - [Would_vote_for_a_candidate_or_pa]cct1_other

****** APPENDIX TABLE 3: RESULTS IN DIFFERENT GROUPS OF COUNTRIES (RESULTS PRESENTED IN FIGURE 2)
foreach c in presidentsoffice leftistpresident conditional_enforced compulsory {
	foreach v in 0 1 {
		eststo clear
		xi: svy: mlogit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
			exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais ///
			if pais != 22 & `c' == `v', base(2)
		eststo
		esttab, b(3) se(3) pr2 ar2 nogaps nopar wide unstack star(^ .10 * .05 ** .01 *** .001) keep(cct1newr) label 
		tab1 pais if e(sample)
	}
}

***** APPENDIX FIGURE 1. MARGINAL EFFECTS BY COUNTRY TYPE IN NINE COUNTRIES, USING CCT1B
global results ""
foreach c in compulsory conditional_enforced presidentsoffice leftistpresident {
	foreach v in 0 1 {
		forvalues i = 1/4 {
			xi: svy: mlogit vb20 cct1br gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
				exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais ///
				if cct1b_asked == 1 & `c' == `v', base(2)
			preserve
			egen tag_pais_cct1br = tag(pais cct1br) if e(sample)
			foreach j in gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
				exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community {
					egen mean_`j' = mean(`j'), by(pais)
					replace `j' = mean_`j' if e(sample)
				}
			margins if tag_pais_cct1br == 1, dydx(cct1br) predict(outcome(`i')) post
			parmest, format(estimate min95 max95 p %8.3f p %8.1e) idstr(`c'`v'_outcome`i') saving(prob_`c'`v'_outcome`i', replace) flist(results)
			restore
		}
	}
}
preserve
clear 
append using $results
egen outcome = ends(idstr), punct(_outcome) tail
	destring outcome, replace
	replace outcome = 5-outcome
	lab def outcome 4 "Abstain" 3 "Incumbent Vote" 2 "Opposition Vote" 1 "Blank Vote"
	lab val outcome outcome
egen countrytype2 = ends(idstr), punct(_outcome) head
	encode countrytype2, g(countrytype)
	lab def countrytype 1 "Voluntary/Compulsory Unenforced" 2 "Compulsory Voting" 3 "No Conditionalities/Unenforced" 4 "Conditionalities" ///
		5 "Centrist/Rightist President" 6 "Leftist President" 7 "Agency Control of Program" 8 "Presidential Control", modify
	lab val countrytype countrytype
drop countrytype2 idstr parm
g countrytype_outcome = (countrytype - 1)*5 + outcome if countrytype < 3
replace countrytype_outcome = (countrytype -1)*5 + outcome + 1 if countrytype > 2 & countrytype < 5
replace countrytype_outcome = (countrytype -1)*5 + outcome + 2 if countrytype > 4 & countrytype < 7
replace countrytype_outcome = (countrytype -1)*5 + outcome + 3 if countrytype > 6 
graph twoway (bar estimate countrytype_outcome if outcome == 1, horizontal lcolor(black) fcolor(gs16)) ///
	(bar estimate countrytype_outcome if outcome == 2, horizontal lcolor(black) fcolor(gs11)) ///
	(bar estimate countrytype_outcome if outcome == 3, horizontal lcolor(black) fcolor(gs6)) ///
	(bar estimate countrytype_outcome if outcome == 4, horizontal lcolor(black) fcolor(gs1)) ///
	(rspike min95 max95 countrytype_outcome, horizontal color(black) lwidth(vthin)), ///
	legend(order(4 "Abstain" 3 "Incumbent" 2 "Opposition" 1 "Blank Vote") size(vsmall)) xline(0, lcolor(black) lwidth(vthin)) ///
	title("Marginal Effect of Country's Biggest Assistance" "Program on Outcome, By Country Type," "in Nine Countries with Major Programs", ///
	color(black) size(medium) margin(medium) span) ///
	xtitle("") xlabel(, format(%9.2f) grid) ///
	ytitle("") ylabel(6 "VOTING LEGISLATION" 4 "Voluntary/" 3 "Unenforced (N=3)" 9 "Compulsory (N=6)" ///
		17 "CONDITIONALITIES" 15 "None/Unenforced (N=2)" 20 "Enforced (N=7)" ///
		28 "IDEOLOGY OF PRESIDENT" 26 "Centrist/Rightist (N=4)" 31 "Leftist (N=5)" ///
		39 "CONTROL OF PROGRAM" 37 "Agency (N=6)" 42 "President (N=3)", angle(horizontal) notick nogrid labsize(small)) ///
	note("NOTE: Effects represent the change in probability of each outcome" ///
	"for recipients minus non-recipients, for each country type, based" ///
	"on multinomial logistic regression models as specified in Table 2.", span) ///
	ysize(9) graphregion(fcolor(white)) saving("Memo Figure 1.gph", replace)
restore



***************************** VI. FOOTNOTES AND IN TEXT DISCUSSION **************************************************************************************
**** FOOTNOTES 6 AND 7: ITEM NON-RESPONSE CALCULATIONS
foreach var of varlist vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes exc6 vic1extr EFICGOV rolestado ///
	edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community {
    local n=`n'+1
    local c=`n'-1
    recode `var' (. .a .b .c=1) (else=0), g(`var'_m)
    svy: mean `var'_m
    matrix M`n'=e(b)*100
        if "`var'"=="vb20" {
            matrix L`n'=M`n'
            }
        else {
            matrix L`n'=L`c'\M`n'
            }
    drop `var'_m
}
matrix list L22

**** FOOTNOTE 18: MAIN MODEL AS MULTINOMIAL *PROBIT* RATHER THAN LOGIT
eststo clear
xi: svy: mprobit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if pais != 22
eststo
esttab, b(3) se(3) pr2 ar2 nogaps nopar wide star(^ .10 * .05 ** .01 *** .001) label 
***** PREDICTED PROBS
forvalues i = 1/4 {
	xi: svy: mprobit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
		exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if pais != 22
	preserve
		egen tag_pais_cct1newr = tag(pais cct1newr) if e(sample)
		foreach j in gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
			exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community {
				egen mean_`j' = mean(`j'), by(pais)
				replace `j' = mean_`j' if e(sample)
			}
		margins if tag_pais_cct1new == 1, at(cct1newr=(0 1)) predict(outcome(`i')) 
	restore
}

******* FOOTNOTE 20: EXCLUDING THE NON-REGISTERED
eststo clear
xi: svy: mlogit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if pais != 22
eststo 
xi: svy: mlogit vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community i.pais if pais != 22 & vb1 == 1
eststo
esttab, b(3) se(3) pr2 ar2 nogaps nopar wide star(^ .10 * .05 ** .01 *** .001) keep(cct1newr) label 

******** IN-TEXT DISCUSSION: THE MAIN EFFECT OF EACH OF THE HIERARCHICAL VARIABLES ON VOTE OUTCOMES
nicelylabelleddummies vb20, g(votechoice)
rename votechoice1 abstain
rename votechoice2 incumbent
rename votechoice3 opposition
rename votechoice4 blank
foreach var of varlist abstain incumbent opposition blank {
	g mn_`var' = .
	forvalues i = 1/24 {
		svy: mean `var' if country == `i'
		matrix M`var'_`i'=e(b)*100
		svmat M`var'_`i', names(mn_`var'_country`i')
		egen mn2_`var'_country`i' = mean(mn_`var'_country`i')
		replace mn_`var' = mn2_`var'_country`i' if country == `i'
		drop mn_`var'_country`i' mn2_`var'_country`i'
	}
}
preserve
	egen tagcountry = tag(country)
	keep if tagcountry == 1
	pwcorr mn_* compulsory conditional_enforced presidentsoffice leftistpresident, obs sig
	tabstat mn_*, by(compulsory)
	tabstat mn_*, by(conditional_enforced) 
	tabstat mn_*, by(presidentsoffice) 
	tabstat mn_*, by(leftistpresident)
restore


***************************** VII. PREPARATION OF DATA FOR EXPORT TO HLM SOFTWARE ***************************************************************************
preserve
drop if compulsory == . | conditional_enforced == . | presidentsoffice == . 
sort pais
keep vb20 cct1newr gov_pid opp_pid soct1r idio1r quintall unemployment incomedes ///
	exc6 vic1extr EFICGOV rolestado edr mujer tamanor q2 age_sq eff2r PSA5 ing4r community pais wt
rename community communit // SHORTEN VARIABLE NAMES TO 8 CHARACTERS
rename rolestado rolestad
rename unemployment unemploy
rename incomedes incloss
rename cct1newr SocAssis
recode vb20 (1 = 1) (2 = 4) (3 = 2) (4 = 3), g(vb20_r) // IN HLM, THE LAST CATEGORY IS ALWAYS THE EXCLUDED ONE
drop if vb20_r >= . | SocAssis >= . | gov_pid >= . | opp_pid >= . | soct1r >= . | idio1r >= . | ///
	quintall >= . | unemploy >= . | incloss >= . | exc6 >= . | vic1extr >= . | EFICGOV >= . | rolestad >= . | edr >= . | ///
	mujer >= . | tamanor >= . | q2 >= . | age_sq >= . | eff2r >= . | PSA5 >= . | ing4r >= . | communit >= . | pais >= . | wt >= . // ELIMINATE MISSING VARS
drop vb20 
saveold "hlm_individdata.dta", replace
restore

preserve
egen tag_pais = tag(pais)
keep if tag_pais == 1
sort pais
drop if compulsory == . | conditional_enforced == . | presidentsoffice == . 
keep compulsory conditional_enforced presidentsoffice leftistpresident pais 
rename compulsory compulso
rename conditional conditio
rename presidentsoffice presoffc
rename leftistpresident leftist
saveold "hlm_countrydata.dta", replace
restore


***************************** VIII. CODE FOR FIGURE BASED ON HIERARCHICAL ANALYSIS USING HLM SOFTWARE *******************************************************
**** THE FOLLOWING PREDICTED PROBS SET ALL NON-DICHOTOMOUS CONTROL VARIABLES CENTERED AT THEIR COUNTRY-LEVEL MEANS AND DICHOTOMOUS ONES AT 0.
**** RANDOM EFFECTS NOT INCLUDED IN THE CALCULATION (random effects are centered at 0).

preserve
insheet using "Rep_Data_Layton_Smith_HLMoutput.csv", clear
***** CREATE EXTRA OBSERVATIONS THAT WILL BECOME THE FOURTH CATEGORY, CODE CATEGORY AND MODEL NAMES
	set obs 304
	replace category = 4 if _n > 288
	replace coefficient = 0 if category == 4
	lab def category 1 "Abstain" 2 "Opposition" 3 "Blank/Null" 4 "Incumbent", modify
	lab val category category
	encode model, g(model2)
	drop model
	rename model2 model
	replace model = 1 if _n > 288 & _n <= 292
	replace model = 2 if _n > 292 & _n <= 296
	replace model = 3 if _n > 296 & _n <= 300
	replace model = 4 if _n > 300 
	egen tag_category_model = tag(category model)
****** SET STANDARD VARIABLE NAMES & DROP EXTRA VARS
g varname = varlabel
replace varname = "constant" if _n == 289 | _n == 293 | _n == 297 | _n == 301
replace varname = "cct1newr" if _n == 290 | _n == 294 | _n == 298 | _n == 302
replace varname = "compulsory" if _n == 291 
replace varname = "conditional" if _n == 295
replace varname = "leftist" if varlabel == "leftistpresident" | _n == 299
replace varname = "presidentsoffice" if varlabel == "presidentialcontrol" | _n == 303
replace varname = "cctXcompulsory" if _n == 292
replace varname = "cctXconditional" if _n == 296
replace varname = "cctXleftist" if varlabel == "cctXleftistpresident" | _n == 300
replace varname = "cctXpresidentsoffice" if varlabel == "cctXpresidentialcontrol" | _n == 304
drop varlabel
keep if varname == "constant" | varname == "cct1newr" | varname == "compulsory" | varname == "conditional" | varname == "presidentsoffice" ///
	| varname == "leftist" | varname == "cctXcompulsory" | varname == "cctXconditional" | varname == "cctXpresidentsoffice" ///
	| varname == "cctXleftist" 
sort model category varname
**** SET VALUES OF X'ES	
*** COMPULSORY VOTING
	g cct0_comp0 = (varname == "constant") if model == 1
	g cct1_comp0 = (varname == "constant" | varname == "cct1newr") if model == 1
	g cct0_comp1 = (varname == "constant" | varname == "compulsory") if model == 1
	g cct1_comp1 = (varname == "constant" | varname == "compulsory" | varname == "cctXcompulsory" | varname == "cct1newr") if model == 1
*** CONDITIONALITY
	g cct0_cond0 = (varname == "constant") if model == 2
	g cct1_cond0 = (varname == "constant" | varname == "cct1newr") if model == 2
	g cct0_cond1 = (varname == "constant" | varname == "conditional") if model == 2
	g cct1_cond1 = (varname == "constant" | varname == "conditional" | varname == "cctXconditional" | varname == "cct1newr") if model == 2
*** LEFTIST PRESIDENT
	g cct0_left0 = (varname == "constant") if model == 3
	g cct1_left0 = (varname == "constant" | varname == "cct1newr") if model == 3
	g cct0_left1 = (varname == "constant" | varname == "leftist") if model == 3
	g cct1_left1 = (varname == "constant" | varname == "leftist" | varname == "cctXleftist" | varname == "cct1newr") if model == 3
*** PRESIDENTIAL CONTROL
	g cct0_pres0 = (varname == "constant") if model == 4
	g cct1_pres0 = (varname == "constant" | varname == "cct1newr") if model == 4
	g cct0_pres1 = (varname == "constant" | varname == "presidentsoffice") if model == 4
	g cct1_pres1 = (varname == "constant" | varname == "presidentsoffice" | varname == "cctXpresidentsoffice" | varname == "cct1newr") if model == 4
**** CALCULATE LOGITS AND PREDICTED PROBS
foreach j in cct0_comp0 cct1_comp0 cct0_comp1 cct1_comp1 cct0_cond0 cct1_cond0 cct0_cond1 cct1_cond1 ///
		cct0_left0 cct1_left0 cct0_left1 cct1_left1 cct0_pres0 cct1_pres0 cct0_pres1 cct1_pres1 {
	**** PROBABILITIES
		g b`j' = coefficient*`j'
		by model category: egen catsum_b`j' = total(b`j') if `j' != . 
		g e_catsum_b`j' = exp(catsum_b`j') if tag_category_model == 1 & `j' != .
		egen sum_e_catsum_b`j' = total(e_catsum_b`j' ) if `j' != .
		g prob_`j' = e_catsum_b`j'/(sum_e_catsum_b`j')
		egen prob_`j'_r = mean(prob_`j'), by(category)
		replace prob_`j' = prob_`j'_r
		drop b* catsum_b*  e_catsum_b* sum_e_catsum_b* prob_`j'_r
}
drop if tag_category_model != 1 
egen tag_category = tag(category)
drop if tag_category != 1
keep category prob*
g deltaprob_comp0 = prob_cct1_comp0 - prob_cct0_comp0 
g deltaprob_comp1 = prob_cct1_comp1 - prob_cct0_comp1
g deltaprob_cond0 = prob_cct1_cond0 - prob_cct0_cond0
g deltaprob_cond1 = prob_cct1_cond1 - prob_cct0_cond1
g deltaprob_left0 = prob_cct1_left0 - prob_cct0_left0
g deltaprob_left1 = prob_cct1_left1 - prob_cct0_left1
g deltaprob_pres0 = prob_cct1_pres0 - prob_cct0_pres0
g deltaprob_pres1 = prob_cct1_pres1 - prob_cct0_pres1
drop prob*
xpose, clear varname
drop if _varname == "category"
egen countrytype = seq(), from(1) to(8)
	lab def countrytype 1 `"Voting Voluntary/" "Unenforced Compulsory"' 2 "Compulsory Voting" 3 "No Conditionalities/Unenforced" 4 "Conditionalities" ///
		5 "Centrist/Rightist President" 6 "Leftist President" 7 "Agency Control of Program" 8 "Presidential Control", modify
	lab val countrytype countrytype
drop _varname
rename v1 abstain
rename v2 opposition
rename v3 blank
rename v4 incumbent
lab var abstain "Abstain"
lab var opposition "Opposition"
lab var blank "Blank Vote"
lab var incumbent "Incumbent" 
save "predicted probs (deltas) hierarchical model.dta", replace
**** CODE FOR FIGURE ITSELF
use "predicted probs (deltas) hierarchical model.dta", clear
	append using "predicted probs (deltas) hierarchical model.dta"
	append using "predicted probs (deltas) hierarchical model.dta"
	append using "predicted probs (deltas) hierarchical model.dta"
g estimate = abstain if _n < 9
	replace estimate = incumbent if _n > 8 & _n < 17
	replace estimate = opposition if _n > 16 & _n < 25
	replace estimate = blank if _n > 24 
g outcome = 4 if _n < 9
	replace outcome = 3 if _n > 8 & _n < 17
	replace outcome = 2 if _n > 16 & _n < 25
	replace outcome = 1 if _n > 24
	lab def outcome 4 "Abstain" 3 "Incumbent Vote" 2 "Opposition Vote" 1 "Blank Vote"
	lab val outcome outcome
drop abstain blank incumbent opposition
g countrytype_outcome = (countrytype - 1)*5 + outcome if countrytype < 3
replace countrytype_outcome = (countrytype -1)*5 + outcome + 1 if countrytype > 2 & countrytype < 5
replace countrytype_outcome = (countrytype -1)*5 + outcome + 2 if countrytype > 4 & countrytype < 7
replace countrytype_outcome = (countrytype -1)*5 + outcome + 3 if countrytype > 6 
graph twoway (bar estimate countrytype_outcome if outcome == 1, horizontal lcolor(black) fcolor(gs16)) ///
	(bar estimate countrytype_outcome if outcome == 2, horizontal lcolor(black) fcolor(gs11)) ///
	(bar estimate countrytype_outcome if outcome == 3, horizontal lcolor(black) fcolor(gs6)) ///
	(bar estimate countrytype_outcome if outcome == 4, horizontal lcolor(black) fcolor(gs1)), ///
	legend(order(4 "Abstain" 3 "Incumbent" 2 "Opposition" 1 "Blank Vote") size(vsmall)) xline(0, lcolor(black) lwidth(vthin)) ///
	title("Marginal Effect of Receiving Social Assistance" "on Outcome, Based on Hierarchical Model", color(black) size(medium) margin(medium) span) ///
	xtitle("") xlabel(, format(%9.2f) grid) ///
	ytitle("") ylabel(6 "VOTING LEGISLATION" 4 "Voluntary/" 3 "Unenforced" 9 "Compulsory" ///
		17 "CONDITIONALITIES" 15 "None/Unenforced" 20 "Enforced" ///
		28 "IDEOLOGY OF PRESIDENT" 26 "Centrist/Rightist" 31 "Leftist" ///
		39 "CONTROL OF PROGRAM" 37 "Agency" 42 "President", angle(horizontal) notick nogrid labsize(small)) ///
	note("NOTE: Effects represent the change in probability of each outcome" ///
	"for recipients minus non-recipients, for each country type, based on" ///
	"hierarchical multinomial logit model as specified in Table 3.", span) ///
	ysize(9) graphregion(fcolor(white)) saving("Appendix Figure 1.gph", replace)
restore
